@@ -1,37 +1,23 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <libxfs.h>
-#include <jdm.h>
+#include <xfs/xfs.h>
+#include <xfs/jdm.h>
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -191,7 +177,7 @@ mlog_init1( intgen_t argc, char *argv[ ] )
 		case GETOPT_VERBOSITY:
 			if ( ! optarg || optarg[ 0 ] == '-' ) {
 				fprintf( stderr,
-					 "%s: -%c argument missing\n",
+					 _("%s: -%c argument missing\n"),
 					 progname,
 					 optopt );
 				usage( );
@@ -207,7 +193,7 @@ mlog_init1( intgen_t argc, char *argv[ ] )
 						      &valstr );
 				if ( suboptix < 0 ) {
 					fprintf( stderr,
-						 "%s: -%c argument invalid\n",
+						 _("%s: -%c argument invalid\n"),
 						 progname,
 						 optopt );
 					usage( );
@@ -219,10 +205,10 @@ mlog_init1( intgen_t argc, char *argv[ ] )
 				if ( suboptix < MLOG_SS_CNT ) {
 					if ( ! valstr ) {
 						fprintf( stderr,
-							 "%s: -%c subsystem "
+							 _("%s: -%c subsystem "
 							 "subargument "
 							 "%s requires a "
-							 "verbosity value\n",
+							 "verbosity value\n"),
 							 progname,
 							 optopt,
 						mlog_ss_names[ suboptix ] );
@@ -235,9 +221,9 @@ mlog_init1( intgen_t argc, char *argv[ ] )
 				} else {
 					if ( valstr ) {
 						fprintf( stderr,
-							 "%s: -%c argument "
+							 _("%s: -%c argument "
 							 "does not require "
-							 "a value\n",
+							 "a value\n"),
 							 progname,
 							 optopt );
 						usage( );
@@ -249,8 +235,8 @@ mlog_init1( intgen_t argc, char *argv[ ] )
 				}
 				if ( mlog_level_ss[ ssix ] < 0 ) {
 					fprintf( stderr,
-						 "%s: -%c argument "
-						 "invalid\n",
+						 _("%s: -%c argument "
+						 "invalid\n"),
 						 progname,
 						 optopt );
 					usage( );
@@ -425,7 +411,7 @@ mlog_va( intgen_t levelarg, char *fmt, va_list args )
 		}
 		if ( streamix != -1 && mlog_streamcnt > 1 ) {
 			fprintf( mlog_fp,
-				 "%s%s%s%s: drive %d: ",
+				 _("%s%s%s%s: drive %d: "),
 				 progname,
 				 mlog_tsstr,
 				 mlog_ssstr,
@@ -726,7 +712,7 @@ mlog_exit_flush(void)
 	if (npids > 0) {
 
 		/* print the state of all the streams */
-		fprintf(mlog_fp, "%s: " PROGSTR_CAPS " Summary:\n", progname);
+		fprintf(mlog_fp, _("%s: %s Summary:\n"), progname, PROGSTR_CAPS );
 
 		for (i = 0; i < npids; i++) {
 			stream_state_t state;
@@ -752,8 +738,8 @@ mlog_exit_flush(void)
 			/* print status of this stream */
 			rvp = rv_getdesc(rv);
 			fprintf(mlog_fp,
-				"%s:   stream %d (pid %d) %s "
-				"%s (%s)\n",
+				_("%s:   stream %d (pid %d) %s "
+				"%s (%s)\n"),
 				progname,
 				streamix,
 				pids[i],
@@ -792,7 +778,7 @@ mlog_exit_flush(void)
 	else status_str = exit_strings[mlog_main_exit_code];
 
 	/* now print the overall state of the dump/restore */
-	fprintf(mlog_fp, "%s: " PROGSTR_CAPS " Status: %s\n", progname, status_str);
+	fprintf(mlog_fp, "%s: %s Status: %s\n", progname, PROGSTR_CAPS, status_str);
 	fflush(mlog_fp);
 }
 
