@@ -1,36 +1,22 @@
 /*
- * Copyright (c) 2000-2002 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2002 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <xfs/libxfs.h>
+#include <xfs/xfs.h>
 #include <xfs/jdm.h>
 #include "config.h"
 
@@ -125,28 +111,6 @@ char
 	return rval;
 }
 
-void
-stat64_to_xfsbstat( xfs_bstat_t *dstp, struct stat64 *srcp )
-{
-	memset( ( void * )dstp, 0, sizeof( *dstp ));
-
-	dstp->bs_ino = srcp->st_ino;  /* TODO XXX PORT */
-	dstp->bs_mode = srcp->st_mode;
-	dstp->bs_nlink = srcp->st_nlink;
-	dstp->bs_uid = srcp->st_uid;
-	dstp->bs_gid = srcp->st_gid;
-	dstp->bs_rdev = IRIX_MKDEV(major(srcp->st_rdev), minor(srcp->st_rdev));
-	dstp->bs_blksize = ( int32_t )srcp->st_blksize;
-	dstp->bs_size = srcp->st_size;
-	dstp->bs_atime.tv_sec = srcp->st_atime;
-	dstp->bs_atime.tv_nsec = 0;
-	dstp->bs_mtime.tv_sec = srcp->st_mtime;
-	dstp->bs_mtime.tv_nsec = 0;
-	dstp->bs_ctime.tv_sec = srcp->st_ctime;
-	dstp->bs_ctime.tv_nsec = 0;
-	dstp->bs_blocks = srcp->st_blocks;
-}
-
 intgen_t
 bigstat_iter( jdm_fshandle_t *fshandlep,
 	      intgen_t fsfd,
@@ -165,8 +129,8 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 	__s32 buflenout;
 	xfs_ino_t lastino;
 	intgen_t saved_errno;
-        
-        xfs_fsop_bulkreq_t bulkreq, sbulkreq;
+	intgen_t bulkstatcnt;
+        xfs_fsop_bulkreq_t bulkreq;
 
 	/* stat set with return from callback func
 	 */
@@ -189,7 +153,8 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 	}
 	mlog( MLOG_NITTY + 1,
 	      "calling bulkstat\n" );
-        
+
+	bulkstatcnt = 0;
 	bulkreq.lastip = (__u64 *)&lastino;
 	bulkreq.icount = buflenin;
 	bulkreq.ubuffer = buf;
@@ -219,15 +184,12 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 				mlog( MLOG_NITTY + 1,
 				      "ino %llu needed second bulkstat\n",
 				      p->bs_ino );
-                                sbulkreq.lastip = &p->bs_ino;
-                                sbulkreq.icount = 1;
-                                sbulkreq.ubuffer = p;
-                                sbulkreq.ocount = NULL;
-                                if( ioctl( fsfd, XFS_IOC_FSBULKSTAT_SINGLE, &sbulkreq ) < 0 ) {
-					mlog( MLOG_WARNING,
-					      _("failed to get bulkstat information for inode %llu\n"),
-					      p->bs_ino );
-					continue;
+
+				if( bigstat_one( fsfd, p->bs_ino, p ) < 0 ) {
+				    mlog( MLOG_WARNING,
+					  _("failed to get bulkstat information for inode %llu\n"),
+					  p->bs_ino );
+				    continue;
 				}
 				if ( !p->bs_nlink || !p->bs_mode || !p->bs_ino ) {
 					mlog( MLOG_TRACE,
@@ -254,7 +216,8 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 			if ( pfp ) ( pfp )( PREEMPT_PROGRESSONLY );
 		}
 
-		if ( pfp && ( pfp )( PREEMPT_FULL )) {
+		if ( pfp && (++bulkstatcnt % 10) == 0 &&
+		     ( pfp )( PREEMPT_FULL )) {
 			return EINTR;
 		}
 
@@ -273,33 +236,76 @@ bigstat_iter( jdm_fshandle_t *fshandlep,
 
 /* ARGSUSED */
 intgen_t
-bigstat_one( jdm_fshandle_t *fshandlep,
-	     intgen_t fsfd,
+bigstat_one( intgen_t fsfd,
 	     xfs_ino_t ino,
 	     xfs_bstat_t *statp )
 {
         xfs_fsop_bulkreq_t bulkreq;
-        
-#ifdef SGI_FS_BULKSTAT_SINGLE
-	ASSERT( ino > 0 );
-	return syssgi( SGI_FS_BULKSTAT_SINGLE, fsfd, &ino, statp );
-#else
-	xfs_ino_t lastino;
 	intgen_t count = 0;
-	intgen_t rval;
 
 	ASSERT( ino > 0 );
-	lastino = ino - 1;
-        bulkreq.lastip = (__u64 *)&lastino;
+        bulkreq.lastip = (__u64 *)&ino;
         bulkreq.icount = 1;
         bulkreq.ubuffer = statp;
         bulkreq.ocount = &count;
-        rval = ioctl(fsfd, XFS_IOC_FSBULKSTAT, &bulkreq);
-	if ( count == 0 || lastino != ino ) {
-		return EINVAL;
+	return xfsctl(NULL, fsfd, XFS_IOC_FSBULKSTAT_SINGLE, &bulkreq);
+}
+
+/* call the given callback for each inode group in the filesystem.
+ */
+#define INOGRPLEN	256
+intgen_t
+inogrp_iter( intgen_t fsfd,
+	     intgen_t ( * fp )( void *arg1,
+				intgen_t fsfd,
+				xfs_inogrp_t *inogrp ),
+	     void * arg1,
+	     intgen_t *statp )
+{
+	xfs_ino_t lastino;
+	intgen_t inogrpcnt;
+	xfs_inogrp_t *igrp;
+        xfs_fsop_bulkreq_t bulkreq;
+
+	/* stat set with return from callback func */
+	*statp = 0;
+
+	igrp = malloc(INOGRPLEN * sizeof(xfs_inogrp_t));
+	if (!igrp) {
+		mlog(MLOG_NORMAL | MLOG_ERROR,
+		     _("malloc of stream context failed (%d bytes): %s\n"),
+		     INOGRPLEN * sizeof(xfs_inogrp_t),
+		     strerror(errno));
+		return -1;
 	}
-	return rval;
-#endif
+
+	lastino = 0;
+	inogrpcnt = 0;
+	bulkreq.lastip = (__u64 *)&lastino;
+	bulkreq.icount = INOGRPLEN;
+	bulkreq.ubuffer = igrp;
+	bulkreq.ocount = &inogrpcnt;
+	while (!ioctl(fsfd, XFS_IOC_FSINUMBERS, &bulkreq)) {
+		xfs_inogrp_t *p, *endp;
+
+		if ( inogrpcnt == 0 ) {
+			free(igrp);
+			return 0;
+		}
+		for ( p = igrp, endp = igrp + inogrpcnt ; p < endp ; p++ ) {
+			intgen_t rval;
+
+			rval = ( * fp )( arg1, fsfd, p );
+			if ( rval ) {
+				*statp = rval;
+				free(igrp);
+				return 0;
+			}
+		}
+	}
+
+	free(igrp);
+	return errno;
 }
 
 /* calls the callback for every entry in the directory specified
@@ -424,8 +430,7 @@ diriter( jdm_fshandle_t *fshandlep,
 
 			/* use bigstat
 			 */
-			scrval = bigstat_one( fshandlep,
-					      fsfd,
+			scrval = bigstat_one( fsfd,
 					      p->d_ino,
 					      &statbuf );
 			if ( scrval ) {
