@@ -1,33 +1,19 @@
 /*
- * Copyright (c) 2000-2001 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef UTIL_H
 #define UTIL_H
@@ -89,11 +75,6 @@ extern intgen_t read_buf( char *bufp,
  */
 extern char *strncpyterm( char *s1, char *s2, size_t n );
 
-/* converts a struct stat64 into a xfs_bstat_t. does not fill in fields
- * where info cannot be extracted from struct stat64.
- */
-extern void stat64_to_xfsbstat( xfs_bstat_t *xfsstatp, struct stat64 *statp );
-
 /* bigstat - efficient file status gatherer. presents an iterative
  * callback interface, invoking the caller's callback for each in-use
  * inode. the caller can specify the first ino, and can limit the callbacks
@@ -107,7 +88,7 @@ extern void stat64_to_xfsbstat( xfs_bstat_t *xfsstatp, struct stat64 *statp );
 #define BIGSTAT_ITER_ALL	( ~0 )
 
 extern intgen_t bigstat_iter( jdm_fshandle_t *fshandlep,
-			      intgen_t fsid,
+			      intgen_t fsfd,
 			      intgen_t selector,
 			      xfs_ino_t start_ino,
 			      intgen_t ( * fp )( void *arg1,
@@ -120,11 +101,16 @@ extern intgen_t bigstat_iter( jdm_fshandle_t *fshandlep,
 			      xfs_bstat_t *buf,
 			      size_t buflen );
 
-extern intgen_t bigstat_one( jdm_fshandle_t *fshandlep,
-			     intgen_t fsid,
+extern intgen_t bigstat_one( intgen_t fsfd,
 			     xfs_ino_t ino,
 			     xfs_bstat_t *statp );
 
+extern intgen_t inogrp_iter( intgen_t fsfd,
+			     intgen_t ( * fp )( void *arg1,
+				     		intgen_t fsfd,
+						xfs_inogrp_t *inogrp ),
+			     void * arg1,
+			     intgen_t *statp );
 
 /* calls the callback for every entry in the directory specified
  * by the stat buffer. supplies the callback with a file system
