@@ -1,37 +1,23 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#include <libxfs.h>
-#include <jdm.h>
+#include <xfs/xfs.h>
+#include <xfs/jdm.h>
 
 #include <time.h>
 #include <fcntl.h>
@@ -150,8 +136,8 @@ stobj_find_splitpoint( int fd, invt_seshdr_t *harr, u_int ns, time32_t tm )
 	   really possible, but either way, we split at the last entry.
 	   This will impact the guarantee that invindex tries to give - that
 	   there's always a unique stobj for every session. */
-	mlog( MLOG_VERBOSE | MLOG_INV,
-	      "INV: failed to find a different sh_time to split\n"
+	mlog( MLOG_VERBOSE | MLOG_INV, _(
+	      "INV: failed to find a different sh_time to split\n")
 	     );
 	      
 	return ns - 1;
@@ -972,7 +958,9 @@ stobj_delete_mobj(int fd,
 		for ( j = 0; j < nmfiles; j++ ) {
 			mf = &mfiles[j];
 			if ( !uuid_compare( mf->mf_moid, *moid ) ) {
+#ifdef INVT_DEBUG
 				printf(" found one\n" );
+#endif
 
 /*                                dirty = BOOL_TRUE;	
 
@@ -1024,7 +1012,8 @@ stobj_unpack_sessinfo(
 	/* first make sure that the magic cookie at the beginning is right.
 	   this isn't null-terminated */
 	if (strncmp( p, INVTSESS_COOKIE, strlen( INVTSESS_COOKIE ) ) != 0) {
-		mlog( MLOG_NORMAL | MLOG_INV,"INV: inv_put_session: unknown cookie\n");
+		mlog( MLOG_NORMAL | MLOG_INV, _(
+			"INV: inv_put_session: unknown cookie\n") );
 		return BOOL_FALSE;
 	}
 	/* skip the cookie */
@@ -1063,8 +1052,9 @@ stobj_unpack_sessinfo(
 		/* At this point , don't care about the INV_VERSION. Maybe in future */
 		p += sizeof( inv_version_t ); /* skip the inventory version */
 	} else {
-	        mlog( MLOG_NORMAL | MLOG_INV,"INV: inv_put_session: unknown packed inventory version"
-		      " %d\n", *( inv_version_t *) p);
+	        mlog( MLOG_NORMAL | MLOG_INV, _(
+		      "INV: inv_put_session: unknown packed inventory version"
+		      " %d\n"), *( inv_version_t *) p);
 		return BOOL_FALSE;
 	} 
 
@@ -1264,9 +1254,16 @@ stobj_copy_invsess(int fd,
 			}
 
 			/* copy the mediafile into the exported structure */
-			stobj_convert_mfile( &ises->s_streams[i].st_mediafiles[j],
-					     &mf);
-			
+			if (ises->s_streams[i].st_mediafiles) {
+				stobj_convert_mfile( &ises->s_streams[i].st_mediafiles[j],
+						&mf);
+			} else {
+				mlog(MLOG_ERROR, _(
+					"Failed to get data from media file: "
+					"possible file corruption\n") );
+				mlog_exit_hint(RV_CORRUPT);
+				return -1;
+			}
 		}
 		
 	}
